%global debug_package %{nil}

Group:     System/Kernel and hardware
Summary:   Firmware update EFI binaries
Name:      fwupd-efi
Version:   1.3
Release:   %mkrel 3
License:   LGPLv2+
URL:       https://github.com/fwupd/fwupd-efi
Source0:   https://people.freedesktop.org/~hughsient/releases/%{name}-%{version}.tar.xz

# these are the only architectures supporting UEFI UpdateCapsule
ExclusiveArch: x86_64

BuildRequires: gcc
BuildRequires: meson
BuildRequires: gnu-efi-devel
BuildRequires: pesign

# ease upgrade mga8 -> mga9 (mga#31858)
Conflicts:     fwupd < 1.8.3

%description
fwupd is a project to allow updating device firmware, and this package provides
the EFI binary that is used for updating using UpdateCapsule.

%prep
%autosetup -p1

%build

%meson \
    -Defi_sbat_distro_id="%{efi_vendor}" \
    -Defi_sbat_distro_summary="The %{distribution} Project" \
    -Defi_sbat_distro_pkgname="%{name}" \
    -Defi_sbat_distro_version="%{version}-%{release}" \
    -Defi_sbat_distro_url="http://madb.mageia.org/package/show/name/fwupd-efi/"

%meson_build

%install
%meson_install

# not required yet
rm $RPM_BUILD_ROOT%{_libdir}/pkgconfig/fwupd-efi.pc

# sign fwupd.efi loader
%ifarch x86_64
%global efiarch x64
%endif
%ifarch aarch64
%global efiarch aa64
%endif
%global fwup_efi_fn $RPM_BUILD_ROOT%{_libexecdir}/fwupd/efi/fwupd%{efiarch}.efi
%pesign -s -i %{fwup_efi_fn} -o %{fwup_efi_fn}.tmp
%define __pesign_client_cert fwupd-signer
%pesign -s -i %{fwup_efi_fn}.tmp -o %{fwup_efi_fn}.signed
rm -vf %{fwup_efi_fn}.tmp

%files
%doc README.md AUTHORS
%license COPYING
%{_libexecdir}/fwupd/efi/*.efi
%{_libexecdir}/fwupd/efi/*.efi.signed



%changelog
* Tue May 02 2023 daviddavid <daviddavid> 1.3-3.mga9
+ Revision: 1955603
- use mageia sbat_distro id and summary

* Fri Sep 02 2022 neoclust <neoclust> 1.3-2.mga9
+ Revision: 1883411
- Add conflicts to ease upgrade (mga#31858)

* Fri Apr 15 2022 tv <tv> 1.3-1.mga9
+ Revision: 1850231
- 1.3

* Thu Mar 24 2022 umeabot <umeabot> 1.2-2.mga9
+ Revision: 1824606
- Mageia 9 Mass Rebuild

* Sun Jan 23 2022 tv <tv> 1.2-1.mga9
+ Revision: 1769562
- 1.2
- Do not build on aarch64 since it always fail

* Tue Jun 22 2021 tv <tv> 1.1-1.mga9
+ Revision: 1731698
- Do not build on aarch64 since it always fail
- 1.1
- imported package fwupd-efi


* Thu May 13 2021 Thierry Vignaud <tv@mageia.org> 1.0-1.mga9
- Initial import, split from the main fwupd package
